from ttgtcanvas2 import WorldModel, Maze
import random

def init(world):  
    choice = random.randint(1,10)
    world.add_object(1, 1, "daisy", 5)
    world.add_drop_obj_goal(5,1, "daisy", 1)
    

def generate_maze():
    world =  WorldModel('./worlds/test.json', init)
    return Maze(world)


DEFAULT_ASSET_URL="https://totogoto.com/assets/python_project/images/"
DEFAULT_OBJECTS = [
    "1",
    "2",
    "3",
    "4",
    "5",
    "apple_goal",
    "apple",
    "around3_sol",
    "banana_goal",
    "banana",
    "beeper_goal",
    "box_goal",
    "box",
    "bricks",
    "bridge",
    "carrot_goal",
    "carrot",
    "daisy_goal",
    "daisy",
    "dandelion_goal",
    "dandelion",
    "desert",
    "east_goal",
    "east_grid",
    "east",
    "external_link",
    "favicon",
    "fence_double",
    "fence_left",
    "fence_right",
    "fence_vertical",
    "fire1",
    "fire2",
    "fire",
    "flame1",
    "flame2",
    "flame3",
    "flame4",
    "flame5",
    "flame6",
    "fromage",
    "grass_bottom_left",
    "grass_bottom_right",
    "grass",
    "grass_top_left",
    "grass_top_right",
    "gravel",
    "green_home_tile",
    "highlight",
    "house",
    "hurdles",
    "ice",
    "leaf_goal",
    "leaf",
    "logs",
    "magnifying_no",
    "magnifying_yes",
    "mailto",
    "mort",
    "mud",
    "north",
    "not_ok",
    "ok",
    "open_program",
    "orange_goal",
    "orange",
    "ouch",
    "pale_grass",
    "pause",
    "plain_e",
    "plain_n",
    "plain_s",
    "plain_w",
    "play",
    "poison",
    "racing_flag",
    "rat_e",
    "rat_n",
    "rat_s",
    "rat_w",
    "reeborg_judkis",
    "reload",
    "resize",
    "reverse_step",
    "save_program",
    "scorpion",
    "seed",
    "simple_path",
    "sp_e",
    "sp_n",
    "sp_s",
    "sp_w",
    "square_goal",
    "square",
    "stalactite2",
    "stalactite",
    "star_goal",
    "star",
    "step",
    "stop",
    "strawberry_goal",
    "strawberry",
    "student",
    "teleport",
    "tile_colour",
    "token_goal",
    "token",
    "transparent_tile",
    "triangle_goal",
    "triangle",
    "tulip_goal",
    "tulip",
    "water2",
    "water3",
    "water4",
    "water5",
    "water6",
    "water_bucket",
    "water",
    "east_arrow",
    "north_arrow",
    "west_arrow",
    "south_arrow"
]


DEFAULT_TILE_MAP = {tile: "{}{}.png".format(DEFAULT_ASSET_URL, tile) for tile in DEFAULT_OBJECTS }
